@@ -1,6 +1,6 @@
 #pragma once
-#include <catch2/catch.hpp>
 #include <panda/net/sockaddr.h>
+#include <catch2/catch_test_macros.hpp>
 
 using namespace panda;
 using namespace panda::net;
